==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/medialive/kotlin/inputs/ChannelEncoderSettingsAudioDescriptionRemixSettingsChannelMappingInputChannelLevelArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.medialive.kotlin.inputs

import com.pulumi.aws.medialive.inputs.ChannelEncoderSettingsAudioDescriptionRemixSettingsChannelMappingInputChannelLevelArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property gain
 * @property inputChannel
 */
public data class
ChannelEncoderSettingsAudioDescriptionRemixSettingsChannelMappingInputChannelLevelArgs(
    public val gain: Output<Int>,
    public val inputChannel: Output<Int>,
) :
    ConvertibleToJava<com.pulumi.aws.medialive.inputs.ChannelEncoderSettingsAudioDescriptionRemixSettingsChannelMappingInputChannelLevelArgs> {
    override fun toJava():
        com.pulumi.aws.medialive.inputs.ChannelEncoderSettingsAudioDescriptionRemixSettingsChannelMappingInputChannelLevelArgs =
        com.pulumi.aws.medialive.inputs.ChannelEncoderSettingsAudioDescriptionRemixSettingsChannelMappingInputChannelLevelArgs.builder()
            .gain(gain.applyValue({ args0 -> args0 }))
            .inputChannel(inputChannel.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ChannelEncoderSettingsAudioDescriptionRemixSettingsChannelMappingInputChannelLevelArgs].
 */
@PulumiTagMarker
public class
ChannelEncoderSettingsAudioDescriptionRemixSettingsChannelMappingInputChannelLevelArgsBuilder
internal constructor() {
    private var gain: Output<Int>? = null

    private var inputChannel: Output<Int>? = null

    /**
     * @param value
     */
    @JvmName("iwnhfufrlgloeips")
    public suspend fun gain(`value`: Output<Int>) {
        this.gain = value
    }

    /**
     * @param value
     */
    @JvmName("dayumjlcwqkdppmv")
    public suspend fun inputChannel(`value`: Output<Int>) {
        this.inputChannel = value
    }

    /**
     * @param value
     */
    @JvmName("cippjriihpnmiqbl")
    public suspend fun gain(`value`: Int) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.gain = mapped
    }

    /**
     * @param value
     */
    @JvmName("xjqegmumbcdhjelr")
    public suspend fun inputChannel(`value`: Int) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.inputChannel = mapped
    }

    internal fun build():
        ChannelEncoderSettingsAudioDescriptionRemixSettingsChannelMappingInputChannelLevelArgs =
        ChannelEncoderSettingsAudioDescriptionRemixSettingsChannelMappingInputChannelLevelArgs(
            gain = gain ?: throw PulumiNullFieldException("gain"),
            inputChannel = inputChannel ?: throw PulumiNullFieldException("inputChannel"),
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/medialive/kotlin/inputs/ChannelEncoderSettingsAudioDescriptionRemixSettingsChannelMappingInputChannelLevelArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.medialive.kotlin.inputs

import com.pulumi.aws.medialive.inputs.ChannelEncoderSettingsAudioDescriptionRemixSettingsChannelMappingInputChannelLevelArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property gain
 * @property inputChannel
 */
public data class
ChannelEncoderSettingsAudioDescriptionRemixSettingsChannelMappingInputChannelLevelArgs(
    public val gain: Output<Int>,
    public val inputChannel: Output<Int>,
) :
    ConvertibleToJava<com.pulumi.aws.medialive.inputs.ChannelEncoderSettingsAudioDescriptionRemixSettingsChannelMappingInputChannelLevelArgs> {
    override fun toJava(): com.pulumi.aws.medialive.inputs.ChannelEncoderSettingsAudioDescriptionRemixSettingsChannelMappingInputChannelLevelArgs =
        com.pulumi.aws.medialive.inputs.ChannelEncoderSettingsAudioDescriptionRemixSettingsChannelMappingInputChannelLevelArgs.builder()
            .gain(gain.applyValue({ args0 -> args0 }))
            .inputChannel(inputChannel.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ChannelEncoderSettingsAudioDescriptionRemixSettingsChannelMappingInputChannelLevelArgs].
 */
@PulumiTagMarker
public class
ChannelEncoderSettingsAudioDescriptionRemixSettingsChannelMappingInputChannelLevelArgsBuilder
internal constructor() {
    private var gain: Output<Int>? = null

    private var inputChannel: Output<Int>? = null

    /**
     * @param value
     */
    @JvmName("rtukggkyswfoghju")
    public suspend fun gain(`value`: Output<Int>) {
        this.gain = value
    }

    /**
     * @param value
     */
    @JvmName("dmddpvbvxqvsemwb")
    public suspend fun inputChannel(`value`: Output<Int>) {
        this.inputChannel = value
    }

    /**
     * @param value
     */
    @JvmName("jbkvxjrwvkuqguaw")
    public suspend fun gain(`value`: Int) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.gain = mapped
    }

    /**
     * @param value
     */
    @JvmName("crmnopriyukpwixt")
    public suspend fun inputChannel(`value`: Int) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.inputChannel = mapped
    }

    internal fun build(): ChannelEncoderSettingsAudioDescriptionRemixSettingsChannelMappingInputChannelLevelArgs =
        ChannelEncoderSettingsAudioDescriptionRemixSettingsChannelMappingInputChannelLevelArgs(
            gain = gain ?: throw PulumiNullFieldException("gain"),
            inputChannel = inputChannel ?: throw PulumiNullFieldException("inputChannel"),
        )
}
